@@ -10,4 +10,11 @@ def binary_cross_entropy(y ,y_pred) -> np.float64:
     return np.mean(-y * np.log(y_pred) - (1 - y) * np.log(1 - y_pred))
 
 def binary_cross_entropy_prime(y, y_pred) -> np.ndarray:
-    return ((1 - y) / (1 - y_pred) - y / y_pred) / np.size(y)
\ No newline at end of file
+    return ((1 - y) / (1 - y_pred) - y / y_pred) / np.size(y)
+
+#################################
+# Learning rate decay functions #
+#################################
+def lr_decay(learning_rate, epoch, decay_rate):
+    """Standard learning rate decay algorithm"""
+    return (1 / (1 + decay_rate * epoch)) * learning_rate
\ No newline at end of file
